**Example 1: 示例**

示例

Input: 

```
tccli trocket ModifyMQTTInstance --cli-unfold-argument  \
    --InstanceId mqtt-47ka4rdr \
    --Name sjx0119 \
    --Remark 555
```

Output: 
```
{
    "Error": null,
    "RequestId": null,
    "Response": {
        "RequestId": "9955522b-ac27-46c1-8a16-3ed6f98f9c5c"
    }
}
```

